interactive_gantt_chart library

Classes

GanttChart<T, S>
GanttData<T, S>
Wrapper Class to be rendered in the Gantt chart T is for the main data type S is for the sub data type
GanttSubData<T>
Wrapper Class to be placed inside GanttData This class is used to represent a subtask

Enums

GanttMode